Event/job queue abstraction for generated mediators.
Each runtime adapter provides an implementation of EventQueue so that
the mediator! macro can enqueue and
dequeue typed events without coupling to a specific channel backend.
Traits
- Event
Queue - Async queue used by generated mediators to enqueue events and dequeue them in a background processing loop.